==> 0.3.148.tar.gz: lib/pickerRange.dart <==
import 'package:flutter/foundation.dart';
import 'package:wowit/model.dart';
import 'package:wowit/sqlService.dart';
import 'common.dart';
import 'methods.dart';

class PickerRange {
  static KeyValue getDefaultPicker({String tableName}) {
    if (kDebugMode) {
      if (tableName == null) tableName = "";
      return KeyValue(
          -1, -1, "Chưa nhập liệu cho drop dơn này: " + tableName.toString());
    } else {
      return KeyValue(-1, -1, "--");
    }
  }

  static init() async {
    try {
      var ds = await SQLService.execute('sp_dsPickerRange');
      if (ds.length == 0) {
        return;
      }
      var dtData = ds["sp_dsPickerRange"];
      for (var row in dtData) {
        String tableName = Methods.getString(row, 'tableName');
        bool isRange = Methods.getBool(row, 'isRange');
        if (tableName == "") continue;
        print("PickerRange init: " + tableName);
        if (isRange) {
          await PickerRange.initDataRange(tableName);
        } else {
          await PickerRange.initDataPicker(tableName);
        }
      }
    } catch (ex) {
      print("PickerRange init exception: " + ex.toString());
    }
  }

  static String getDataPicker(List<KeyValue> data, int id,
      {String defaultValue = ""}) {
    for (int i = 0; i < data.length; i++) {
      try {
        if (data[i].valueMember == id) {
          return data[i].displayMember;
        }
      } catch (ex) {
        print('getDataPicker ex:' + ex.toString());
      }
    }

    return defaultValue;
  }

  static List<KeyValue> getValueDataPicker(String tableName,
      {int parentId = -1}) {
    if (Common.mapPicker.containsKey(tableName)) {
      if (parentId == null || parentId == -1)
        return Common.mapPicker[tableName];
      List<KeyValue> data = Common.mapPicker[tableName];
      List<KeyValue> lst = [];
      for (int i = 0; i < data.length; i++) {
        if (data[i].parentValue == parentId) {
          lst.add(data[i]);
        }
      }
      if (lst.length == 0 && parentId == -1)
        lst.add(PickerRange.getDefaultPicker());
      return lst;
    } else
      SQLService.execute('sp_AddPickerRange',
          params: {'@tableName': tableName});
    return [PickerRange.getDefaultPicker()];
  }

  static Future<List<KeyValue>> initDataPicker(String tableName,
      {bool override = false}) async {
    if (Common.mapPicker.containsKey(tableName) && !override)
      return Common.mapPicker[tableName];
    List<KeyValue> listVal = [];
    try {
      var ds = await SQLService.execute('sp_getValueDataPicker',
          params: {'@tableName': tableName});
      if (ds.length == 0) return listVal;
      var dtData = ds["sp_getValueDataPicker"];
      for (var row in dtData) {
        int id = Methods.getInt(row, 'ID', defaultValue: -1);
        int parentId = Methods.getInt(row, 'parentId');
        String title = Methods.getString(row, 'title');
        if (id < 0) continue;
        listVal.add(KeyValue(parentId, id, title));
      }
      if (!Common.mapPicker.containsKey(tableName))
        Common.mapPicker[tableName] = listVal;
    } catch (ex) {
      print('[Exception] getValueDataPicker: ' + ex.toString());
    }
    print('getValueDataPicker: ' +
        tableName +
        ' count: ' +
        listVal.length.toString());
    return listVal;
  }

  static Map<int, RangeValue> getValueDataRange(String tableName) {
    if (Common.mapRange.containsKey(tableName)) {
      return Common.mapRange[tableName];
    } else {
      SQLService.execute('sp_AddPickerRange',
          params: {'@tableName': tableName});
    }
    return {};
  }

  static Future<Map<int, RangeValue>> initDataRange(String tableName,
      {bool override = false}) async {
    if (Common.mapRange.containsKey(tableName) && !override)
      return Common.mapRange[tableName];
    Map<int, RangeValue> listVal = {};
    try {
      var ds = await SQLService.execute('sp_getValueDataRange',
          params: {'@tableName': tableName});
      if (ds.length == 0) return listVal;
      var dtData = ds["sp_getValueDataRange"];
      for (var row in dtData) {
        int id = Methods.getInt(row, 'ID', defaultValue: -1);
        String title = Methods.getString(row, 'title');
        double from = Methods.getDouble(row, 'valFrom', defaultValue: 0);
        double to = Methods.getDouble(row, 'valTo', defaultValue: 0);
        if (id < 0) continue;
        listVal[id] = RangeValue(from, to, title: title);
      }
      if (!Common.mapRange.containsKey(tableName))
        Common.mapRange[tableName] = listVal;
    } catch (ex) {
      print('[Exception] initDataRange: ' + ex.toString());
    }
    print('getValueDataPicker: ' +
        tableName +
        ' count: ' +
        listVal.length.toString());
    return listVal;
  }

  static RangeValue getRangeValueDataPicker(
      Map<int, RangeValue> rangeMap, int id,
      {RangeValue defaultValue = const RangeValue(0, 0)}) {
    return rangeMap[id] ?? defaultValue;
  }
}

==> 0.3.194.tar.gz: lib/pickerRange.dart <==
import 'package:flutter/foundation.dart';
import 'package:wowit/model.dart';
import 'package:wowit/sqlService.dart';
import 'common.dart';
import 'methods.dart';

class PickerRange {
  static KeyValue getDefaultPicker({String tableName}) {
    if (kDebugMode) {
      if (tableName == null) tableName = "";
      return KeyValue(
          -1, -1, "Chưa nhập liệu cho drop dơn này: " + tableName.toString());
    } else {
      return KeyValue(-1, -1, "--");
    }
  }

  static init(List<Map<String, Object>>  dtData) async {
    try {
      if(dtData == null || dtData.isEmpty)
      {
        var ds = await SQLService.execute('sp_dsPickerRange');
        if (ds.length == 0) {
          return;
        }
        dtData = ds["sp_dsPickerRange"];
      }
    
      for (var row in dtData) {
        String tableName = Methods.getString(row, 'tableName');
        bool isRange = Methods.getBool(row, 'isRange');
        if (tableName == "") continue;
        print("PickerRange init: " + tableName);
        if (isRange) {
          await PickerRange.initDataRange(tableName);
        } else {
          await PickerRange.initDataPicker(tableName);
        }
      }
    } catch (ex) {
      print("PickerRange init exception: " + ex.toString());
    }
  }

  static String getDataPicker(List<KeyValue> data, int id,
      {String defaultValue = ""}) {
    for (int i = 0; i < data.length; i++) {
      try {
        if (data[i].valueMember == id) {
          return data[i].displayMember;
        }
      } catch (ex) {
        print('getDataPicker ex:' + ex.toString());
      }
    }

    return defaultValue;
  }

  static List<KeyValue> getValueDataPicker(String tableName,
      {int parentId = -1}) {
    if (Common.mapPicker.containsKey(tableName)) {
      if (parentId == null || parentId == -1)
        return Common.mapPicker[tableName];
      List<KeyValue> data = Common.mapPicker[tableName];
      List<KeyValue> lst = [];
      for (int i = 0; i < data.length; i++) {
        if (data[i].parentValue == parentId) {
          lst.add(data[i]);
        }
      }
      if (lst.length == 0 && parentId == -1) {
        lst.add(PickerRange.getDefaultPicker());
        if (kDebugMode) {
          SQLService.execute('sp_AddPickerRange',
              params: {'@tableName': tableName});
        }
      }
      return lst;
    } else {
      if (kDebugMode) {
        SQLService.execute('sp_AddPickerRange',
            params: {'@tableName': tableName});
      }
    }

    return [PickerRange.getDefaultPicker()];
  }

  static Future<List<KeyValue>> initDataPicker(String tableName,
      {bool override = false}) async {
    if (Common.mapPicker.containsKey(tableName) && !override)
      return Common.mapPicker[tableName];
    List<KeyValue> listVal = [];
    try {
      var ds = await SQLService.execute('sp_getValueDataPicker',
          params: {'@tableName': tableName});
      if (ds.length == 0) return listVal;
      var dtData = ds["sp_getValueDataPicker"];
      for (var row in dtData) {
        int id = Methods.getInt(row, 'ID', defaultValue: -1);
        int parentId = Methods.getInt(row, 'parentId');
        String title = Methods.getString(row, 'title');
        if (id < 0) continue;
        listVal.add(KeyValue(parentId, id, title));
      }
      Common.mapPicker[tableName] = listVal;
    } catch (ex) {
      print('[Exception] getValueDataPicker: ' + ex.toString());
    }
    print('getValueDataPicker: ' +
        tableName +
        ' count: ' +
        listVal.length.toString());
    return listVal;
  }

  static Map<int, RangeValue> getValueDataRange(String tableName) {
    if (Common.mapRange.containsKey(tableName)) {
      return Common.mapRange[tableName];
    } else if (kDebugMode) {
      SQLService.execute('sp_AddPickerRange',
          params: {'@tableName': tableName});
    }
    return {};
  }

  static Future<Map<int, RangeValue>> initDataRange(String tableName,
      {bool override = false}) async {
    if (Common.mapRange.containsKey(tableName) && !override)
      return Common.mapRange[tableName];
    Map<int, RangeValue> listVal = {};
    try {
      var ds = await SQLService.execute('sp_getValueDataRange',
          params: {'@tableName': tableName});
      if (ds.length == 0) return listVal;
      var dtData = ds["sp_getValueDataRange"];
      for (var row in dtData) {
        int id = Methods.getInt(row, 'ID', defaultValue: -1);
        String title = Methods.getString(row, 'title');
        double from = Methods.getDouble(row, 'valFrom', defaultValue: 0);
        double to = Methods.getDouble(row, 'valTo', defaultValue: 0);
        if (id < 0) continue;
        listVal[id] = RangeValue(from, to, title: title);
      }
      Common.mapRange[tableName] = listVal;
    } catch (ex) {
      print('[Exception] initDataRange: ' + ex.toString());
    }
    print('getValueDataPicker: ' +
        tableName +
        ' count: ' +
        listVal.length.toString());
    return listVal;
  }

  static RangeValue getRangeValueDataPicker(
      Map<int, RangeValue> rangeMap, int id,
      {RangeValue defaultValue = const RangeValue(0, 0)}) {
    return rangeMap[id] ?? defaultValue;
  }
}
